@@ -50,5 +50,5 @@ class HasContext:
         )
 
     def get_microtime(self):
-        time_value = float(time.time())
-        return (round(time_value, 4))
+        time_value = time.time() * 1000
+        return float(round(time_value, 0))
